linux-kernel.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
From: Pu Wen <puwen@hygon.cn>
To: tglx@linutronix.de, mingo@redhat.com, hpa@zytor.com,
	x86@kernel.org, thomas.lendacky@amd.com, bp@alien8.de,
	pbonzini@redhat.com, tony.luck@intel.com
Cc: linux-kernel@vger.kernel.org, linux-arch@vger.kernel.org,
	linux-edac@vger.kernel.org, Pu Wen <puwen@hygon.cn>
Subject: [PATCH v3 11/17] x86/mce: enable Hygon support to MCE infrastructure
Date: Sat, 11 Aug 2018 21:28:49 +0800	[thread overview]
Message-ID: <d9ade02d30a6b6357fc32254cfa1c6bf8232a019.1533989493.git.puwen@hygon.cn> (raw)
In-Reply-To: <cover.1533989492.git.puwen@hygon.cn>

Hygon machine check arch is similar to AMD family 17h. To enable the MCE
infrastructure support, add CPU vendor check for Hygon to share the code
path of AMD.

Add hygon mce init function mce_hygon_feature_init() to minimize further
maintenance effort.

Signed-off-by: Pu Wen <puwen@hygon.cn>
---
 arch/x86/include/asm/mce.h                |  5 +++++
 arch/x86/kernel/cpu/mcheck/mce-severity.c |  3 ++-
 arch/x86/kernel/cpu/mcheck/mce.c          | 21 +++++++++++++++------
 3 files changed, 22 insertions(+), 7 deletions(-)

diff --git a/arch/x86/include/asm/mce.h b/arch/x86/include/asm/mce.h
index 8c7b3e5..0af3b0e 100644
--- a/arch/x86/include/asm/mce.h
+++ b/arch/x86/include/asm/mce.h
@@ -213,6 +213,11 @@ static inline void mce_amd_feature_init(struct cpuinfo_x86 *c) { }
 static inline int umc_normaddr_to_sysaddr(u64 norm_addr, u16 nid, u8 umc, u64 *sys_addr) { return -EINVAL; };
 #endif
 
+static inline void mce_hygon_feature_init(struct cpuinfo_x86 *c)
+{
+	return mce_amd_feature_init(c);
+}
+
 int mce_available(struct cpuinfo_x86 *c);
 bool mce_is_memory_error(struct mce *m);
 
diff --git a/arch/x86/kernel/cpu/mcheck/mce-severity.c b/arch/x86/kernel/cpu/mcheck/mce-severity.c
index f34d89c..44396d5 100644
--- a/arch/x86/kernel/cpu/mcheck/mce-severity.c
+++ b/arch/x86/kernel/cpu/mcheck/mce-severity.c
@@ -336,7 +336,8 @@ int (*mce_severity)(struct mce *m, int tolerant, char **msg, bool is_excp) =
 
 void __init mcheck_vendor_init_severity(void)
 {
-	if (boot_cpu_data.x86_vendor == X86_VENDOR_AMD)
+	if (boot_cpu_data.x86_vendor == X86_VENDOR_AMD ||
+	    boot_cpu_data.x86_vendor == X86_VENDOR_HYGON)
 		mce_severity = mce_severity_amd;
 }
 
diff --git a/arch/x86/kernel/cpu/mcheck/mce.c b/arch/x86/kernel/cpu/mcheck/mce.c
index 8c50754..65d13f8 100644
--- a/arch/x86/kernel/cpu/mcheck/mce.c
+++ b/arch/x86/kernel/cpu/mcheck/mce.c
@@ -274,7 +274,8 @@ static void print_mce(struct mce *m)
 {
 	__print_mce(m);
 
-	if (m->cpuvendor != X86_VENDOR_AMD)
+	if (m->cpuvendor != X86_VENDOR_AMD &&
+	    m->cpuvendor != X86_VENDOR_HYGON)
 		pr_emerg_ratelimited(HW_ERR "Run the above through 'mcelog --ascii'\n");
 }
 
@@ -512,9 +513,9 @@ static int mce_usable_address(struct mce *m)
 
 bool mce_is_memory_error(struct mce *m)
 {
-	if (m->cpuvendor == X86_VENDOR_AMD) {
+	if (m->cpuvendor == X86_VENDOR_AMD ||
+	    m->cpuvendor == X86_VENDOR_HYGON) {
 		return amd_mce_is_memory_error(m);
-
 	} else if (m->cpuvendor == X86_VENDOR_INTEL) {
 		/*
 		 * Intel SDM Volume 3B - 15.9.2 Compound Error Codes
@@ -540,7 +541,9 @@ EXPORT_SYMBOL_GPL(mce_is_memory_error);
 
 static bool mce_is_correctable(struct mce *m)
 {
-	if (m->cpuvendor == X86_VENDOR_AMD && m->status & MCI_STATUS_DEFERRED)
+	if ((m->cpuvendor == X86_VENDOR_AMD ||
+	     m->cpuvendor == X86_VENDOR_HYGON) &&
+	    (m->status & MCI_STATUS_DEFERRED))
 		return false;
 
 	if (m->status & MCI_STATUS_UC)
@@ -1725,7 +1728,8 @@ static int __mcheck_cpu_ancient_init(struct cpuinfo_x86 *c)
  */
 static void __mcheck_cpu_init_early(struct cpuinfo_x86 *c)
 {
-	if (c->x86_vendor == X86_VENDOR_AMD) {
+	if (c->x86_vendor == X86_VENDOR_AMD ||
+	    c->x86_vendor == X86_VENDOR_HYGON) {
 		mce_flags.overflow_recov = !!cpu_has(c, X86_FEATURE_OVERFLOW_RECOV);
 		mce_flags.succor	 = !!cpu_has(c, X86_FEATURE_SUCCOR);
 		mce_flags.smca		 = !!cpu_has(c, X86_FEATURE_SMCA);
@@ -1766,6 +1770,9 @@ static void __mcheck_cpu_init_vendor(struct cpuinfo_x86 *c)
 		mce_amd_feature_init(c);
 		break;
 		}
+	case X86_VENDOR_HYGON:
+		mce_hygon_feature_init(c);
+		break;
 	case X86_VENDOR_CENTAUR:
 		mce_centaur_feature_init(c);
 		break;
@@ -1991,12 +1998,14 @@ static void mce_disable_error_reporting(void)
 static void vendor_disable_error_reporting(void)
 {
 	/*
 	 * Don't clear on Intel or AMD CPUs. Some of these MSRs are socket-wide.
 	 * Disabling them for just a single offlined CPU is bad, since it will
 	 * inhibit reporting for all shared resources on the socket like the
 	 * last level cache (LLC), the integrated memory controller (iMC), etc.
 	 */
 	if (boot_cpu_data.x86_vendor == X86_VENDOR_INTEL ||
+	    boot_cpu_data.x86_vendor == X86_VENDOR_HYGON ||
 	    boot_cpu_data.x86_vendor == X86_VENDOR_AMD)
 		return;
 
@@ -1991,12 +1998,14 @@ static void mce_disable_error_reporting(void)
 {
 	/*
-	 * Don't clear on Intel or AMD CPUs. Some of these MSRs are socket-wide.
+	 * Don't clear on Intel or AMD or Hygon CPUs. Some of these MSRs
+	 * are socket-wide.
 	 * Disabling them for just a single offlined CPU is bad, since it will
 	 * inhibit reporting for all shared resources on the socket like the
-- 
2.7.4


  parent reply	other threads:[~2018-08-11 13:29 UTC|newest]

Thread overview: 37+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2018-08-11 13:25 [PATCH v3 00/17] Add support for Hygon Dhyana Family 18h processor Pu Wen
2018-08-11 13:25 ` [PATCH v3 01/17] x86/cpu: create Dhyana init file and register new cpu_dev to system Pu Wen
2018-08-11 13:26 ` [PATCH v3 02/17] x86/cache: get cache size/leaves and setup cache cpumap for Dhyana Pu Wen
2018-08-11 13:26 ` [PATCH v3 03/17] x86/mtrr: get MTRR number and support TOP_MEM2 Pu Wen
2018-08-11 13:26 ` [PATCH v3 04/17] x86/smpboot: smp init nodelay and no flush caches before sleep Pu Wen
2018-08-11 13:27 ` [PATCH v3 05/17] x86/perfctr: return perf counter and event selection bit offset Pu Wen
2018-08-11 13:27 ` [PATCH v3 06/17] x86/nops: init ideal_nops for Hygon Pu Wen
2018-08-11 13:27 ` [PATCH v3 07/17] x86/pci: add Hygon PCI vendor and northbridge support Pu Wen
2018-08-13 22:14   ` Bjorn Helgaas
2018-08-14  4:56     ` Pu Wen
2018-08-11 13:27 ` [PATCH v3 08/17] x86/apic: add modern APIC support for Hygon Pu Wen
2018-08-11 13:28 ` [PATCH v3 09/17] x86/bugs: add lfence mitigation to spectre v2 and no meltdown " Pu Wen
2018-08-11 13:28 ` [PATCH v3 10/17] x86/events: enable Hygon support to PMU infrastructure Pu Wen
2018-08-11 13:28 ` Pu Wen [this message]
2018-08-11 13:29 ` [PATCH v3 12/17] x86/kvm: enable Hygon support to KVM infrastructure Pu Wen
2018-08-11 13:29 ` [PATCH v3 13/17] x86/xen: enable Hygon support to Xen Pu Wen
2018-08-11 14:34   ` Boris Ostrovsky
2018-08-12  8:55     ` Juergen Gross
2018-08-12 13:26       ` Boris Ostrovsky
2018-08-16 13:29         ` Pu Wen
2018-08-17  4:37           ` Boris Ostrovsky
2018-08-16 13:22     ` Pu Wen
2018-08-11 13:29 ` [PATCH v3 14/17] driver/acpi: enable Hygon support to ACPI driver Pu Wen
2018-08-12 10:12   ` Rafael J. Wysocki
2018-08-11 13:29 ` [PATCH v3 15/17] driver/cpufreq: enable Hygon support to cpufreq driver Pu Wen
2018-08-12  9:55   ` Rafael J. Wysocki
2018-08-13 16:22     ` Pu Wen
2018-08-14 10:11       ` Rafael J. Wysocki
2018-08-14 10:12   ` Rafael J. Wysocki
2018-08-11 13:30 ` [PATCH v3 16/17] driver/edac: enable Hygon support to AMD64 EDAC driver Pu Wen
2018-08-11 19:56   ` Michael Jin
2018-08-11 20:10     ` Michael Jin
2018-08-13 16:19       ` Pu Wen
2018-08-13 16:17     ` Pu Wen
2018-08-13 16:47       ` Michael Jin
2018-08-13 16:18     ` Pu Wen
2018-08-11 13:30 ` [PATCH v3 17/17] tools/cpupower: enable Hygon support to cpupower tool Pu Wen

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=d9ade02d30a6b6357fc32254cfa1c6bf8232a019.1533989493.git.puwen@hygon.cn \
    --to=puwen@hygon.cn \
    --cc=bp@alien8.de \
    --cc=hpa@zytor.com \
    --cc=linux-arch@vger.kernel.org \
    --cc=linux-edac@vger.kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=mingo@redhat.com \
    --cc=pbonzini@redhat.com \
    --cc=tglx@linutronix.de \
    --cc=thomas.lendacky@amd.com \
    --cc=tony.luck@intel.com \
    --cc=x86@kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).